@@ -1,4 +1,5 @@
 import pytest
+import gc
 from snakeoil.caching import WeakInstMeta
 
 
@@ -40,6 +41,7 @@ class TestWeakInstMeta:
         assert o is kls()
         assert kls.counter == 1
         del o
+        gc.collect()
         kls()
         assert kls.counter == 2
 
@@ -49,6 +51,7 @@ class TestWeakInstMeta:
             o = weak_inst(disable_inst_caching=True)
             assert weak_inst.counter is x
         del o
+        gc.collect()
         o = weak_inst()
         assert o is not weak_inst(disable_inst_caching=True)
 
@@ -157,5 +160,6 @@ class TestWeakInstMeta:
         assert weak_inst.counter == 1
         _myid = id(o)
         del o
+        gc.collect()
         o = weak_inst(unique)
         assert weak_inst.counter == 2
